Documentation
¶
Index ¶
- Variables
- func CacheExpires(r *http.Response) time.Time
- func IsNil(i interface{}) bool
- func PtrBool(v bool) *bool
- func PtrFloat32(v float32) *float32
- func PtrFloat64(v float64) *float64
- func PtrInt(v int) *int
- func PtrInt32(v int32) *int32
- func PtrInt64(v int64) *int64
- func PtrString(v string) *string
- func PtrTime(v time.Time) *time.Time
- type APIClient
- type APIKey
- type APIResponse
- type ApiAuthControllerLoginRequest
- type ApiAuthControllerLogoutRequest
- type ApiAuthControllerSignupRequest
- func (r ApiAuthControllerSignupRequest) Company(company string) ApiAuthControllerSignupRequest
- func (r ApiAuthControllerSignupRequest) ConfirmPassword(confirmPassword string) ApiAuthControllerSignupRequest
- func (r ApiAuthControllerSignupRequest) Email(email string) ApiAuthControllerSignupRequest
- func (r ApiAuthControllerSignupRequest) Execute() (*http.Response, error)
- func (r ApiAuthControllerSignupRequest) FullName(fullName string) ApiAuthControllerSignupRequest
- func (r ApiAuthControllerSignupRequest) Password(password string) ApiAuthControllerSignupRequest
- type ApiSimSwapControllerCheckSimSwapRequest
- func (r ApiSimSwapControllerCheckSimSwapRequest) CheckSimSwapDto(checkSimSwapDto CheckSimSwapDto) ApiSimSwapControllerCheckSimSwapRequest
- func (r ApiSimSwapControllerCheckSimSwapRequest) Execute() (*SimSwapResponseDto, *http.Response, error)
- func (r ApiSimSwapControllerCheckSimSwapRequest) XAPIKey(xAPIKey string) ApiSimSwapControllerCheckSimSwapRequest
- type BasicAuth
- type CheckSimSwapDto
- func (o *CheckSimSwapDto) GetMaxAgeHours() float32
- func (o *CheckSimSwapDto) GetMaxAgeHoursOk() (*float32, bool)
- func (o *CheckSimSwapDto) GetPhoneNumber() string
- func (o *CheckSimSwapDto) GetPhoneNumberOk() (*string, bool)
- func (o *CheckSimSwapDto) HasMaxAgeHours() bool
- func (o CheckSimSwapDto) MarshalJSON() ([]byte, error)
- func (o *CheckSimSwapDto) SetMaxAgeHours(v float32)
- func (o *CheckSimSwapDto) SetPhoneNumber(v string)
- func (o CheckSimSwapDto) ToMap() (map[string]interface{}, error)
- func (o *CheckSimSwapDto) UnmarshalJSON(data []byte) (err error)
- type Configuration
- type DeveloperAuthAPIService
- func (a *DeveloperAuthAPIService) AuthControllerLogin(ctx context.Context) ApiAuthControllerLoginRequest
- func (a *DeveloperAuthAPIService) AuthControllerLoginExecute(r ApiAuthControllerLoginRequest) (*http.Response, error)
- func (a *DeveloperAuthAPIService) AuthControllerLogout(ctx context.Context) ApiAuthControllerLogoutRequest
- func (a *DeveloperAuthAPIService) AuthControllerLogoutExecute(r ApiAuthControllerLogoutRequest) (*http.Response, error)
- func (a *DeveloperAuthAPIService) AuthControllerSignup(ctx context.Context) ApiAuthControllerSignupRequest
- func (a *DeveloperAuthAPIService) AuthControllerSignupExecute(r ApiAuthControllerSignupRequest) (*http.Response, error)
- type GenericOpenAPIError
- type LoginDto
- func (o *LoginDto) GetEmail() string
- func (o *LoginDto) GetEmailOk() (*string, bool)
- func (o *LoginDto) GetPassword() string
- func (o *LoginDto) GetPasswordOk() (*string, bool)
- func (o LoginDto) MarshalJSON() ([]byte, error)
- func (o *LoginDto) SetEmail(v string)
- func (o *LoginDto) SetPassword(v string)
- func (o LoginDto) ToMap() (map[string]interface{}, error)
- func (o *LoginDto) UnmarshalJSON(data []byte) (err error)
- type MappedNullable
- type NullableBool
- type NullableCheckSimSwapDto
- func (v NullableCheckSimSwapDto) Get() *CheckSimSwapDto
- func (v NullableCheckSimSwapDto) IsSet() bool
- func (v NullableCheckSimSwapDto) MarshalJSON() ([]byte, error)
- func (v *NullableCheckSimSwapDto) Set(val *CheckSimSwapDto)
- func (v *NullableCheckSimSwapDto) UnmarshalJSON(src []byte) error
- func (v *NullableCheckSimSwapDto) Unset()
- type NullableFloat32
- type NullableFloat64
- type NullableInt
- type NullableInt32
- type NullableInt64
- type NullableLoginDto
- type NullableSignupDto
- type NullableSimSwapResponseDto
- func (v NullableSimSwapResponseDto) Get() *SimSwapResponseDto
- func (v NullableSimSwapResponseDto) IsSet() bool
- func (v NullableSimSwapResponseDto) MarshalJSON() ([]byte, error)
- func (v *NullableSimSwapResponseDto) Set(val *SimSwapResponseDto)
- func (v *NullableSimSwapResponseDto) UnmarshalJSON(src []byte) error
- func (v *NullableSimSwapResponseDto) Unset()
- type NullableString
- type NullableTime
- type SIMSwapIntelligenceAPIService
- type ServerConfiguration
- type ServerConfigurations
- type ServerVariable
- type SignupDto
- func (o *SignupDto) GetCompany() string
- func (o *SignupDto) GetCompanyOk() (*string, bool)
- func (o *SignupDto) GetConfirmPassword() string
- func (o *SignupDto) GetConfirmPasswordOk() (*string, bool)
- func (o *SignupDto) GetEmail() string
- func (o *SignupDto) GetEmailOk() (*string, bool)
- func (o *SignupDto) GetFullName() string
- func (o *SignupDto) GetFullNameOk() (*string, bool)
- func (o *SignupDto) GetPassword() string
- func (o *SignupDto) GetPasswordOk() (*string, bool)
- func (o *SignupDto) HasCompany() bool
- func (o SignupDto) MarshalJSON() ([]byte, error)
- func (o *SignupDto) SetCompany(v string)
- func (o *SignupDto) SetConfirmPassword(v string)
- func (o *SignupDto) SetEmail(v string)
- func (o *SignupDto) SetFullName(v string)
- func (o *SignupDto) SetPassword(v string)
- func (o SignupDto) ToMap() (map[string]interface{}, error)
- func (o *SignupDto) UnmarshalJSON(data []byte) (err error)
- type SimSwapResponseDto
- func (o *SimSwapResponseDto) GetLastSwappedAt() time.Time
- func (o *SimSwapResponseDto) GetLastSwappedAtOk() (*time.Time, bool)
- func (o *SimSwapResponseDto) GetOperator() string
- func (o *SimSwapResponseDto) GetOperatorOk() (*string, bool)
- func (o *SimSwapResponseDto) GetPhoneNumber() string
- func (o *SimSwapResponseDto) GetPhoneNumberOk() (*string, bool)
- func (o *SimSwapResponseDto) GetProvider() string
- func (o *SimSwapResponseDto) GetProviderOk() (*string, bool)
- func (o *SimSwapResponseDto) GetSwapped() bool
- func (o *SimSwapResponseDto) GetSwappedOk() (*bool, bool)
- func (o *SimSwapResponseDto) HasLastSwappedAt() bool
- func (o SimSwapResponseDto) MarshalJSON() ([]byte, error)
- func (o *SimSwapResponseDto) SetLastSwappedAt(v time.Time)
- func (o *SimSwapResponseDto) SetOperator(v string)
- func (o *SimSwapResponseDto) SetPhoneNumber(v string)
- func (o *SimSwapResponseDto) SetProvider(v string)
- func (o *SimSwapResponseDto) SetSwapped(v bool)
- func (o SimSwapResponseDto) ToMap() (map[string]interface{}, error)
- func (o *SimSwapResponseDto) UnmarshalJSON(data []byte) (err error)
Constants ¶
This section is empty.
Variables ¶
var ( JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`) XmlCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`) )
var ( // ContextAccessToken takes a string oauth2 access token as authentication for the request. ContextAccessToken = contextKey("accesstoken") // ContextAPIKeys takes a string apikey as authentication for the request ContextAPIKeys = contextKey("apiKeys") // ContextServerIndex uses a server configuration from the index. ContextServerIndex = contextKey("serverIndex") // ContextOperationServerIndices uses a server configuration from the index mapping. ContextOperationServerIndices = contextKey("serverOperationIndices") // ContextServerVariables overrides a server configuration variables. ContextServerVariables = contextKey("serverVariables") // ContextOperationServerVariables overrides a server configuration variables using operation specific values. ContextOperationServerVariables = contextKey("serverOperationVariables") )
Functions ¶
func CacheExpires ¶
CacheExpires helper function to determine remaining time before repeating a request.
func PtrFloat32 ¶
PtrFloat32 is a helper routine that returns a pointer to given float value.
func PtrFloat64 ¶
PtrFloat64 is a helper routine that returns a pointer to given float value.
Types ¶
type APIClient ¶
type APIClient struct {
DeveloperAuthAPI *DeveloperAuthAPIService
SIMSwapIntelligenceAPI *SIMSwapIntelligenceAPIService
// contains filtered or unexported fields
}
APIClient manages communication with the Telvri Security API Gateway API v1.0 In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) GetConfig ¶
func (c *APIClient) GetConfig() *Configuration
Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior
type APIKey ¶
APIKey provides API key based authentication to a request passed via context using ContextAPIKey
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the OpenAPI operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
APIResponse stores the API response returned by the server.
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
NewAPIResponse returns a new APIResponse object.
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
NewAPIResponseWithError returns a new APIResponse object with the provided error message.
type ApiAuthControllerLoginRequest ¶
type ApiAuthControllerLoginRequest struct {
ApiService *DeveloperAuthAPIService
// contains filtered or unexported fields
}
func (ApiAuthControllerLoginRequest) Email ¶
func (r ApiAuthControllerLoginRequest) Email(email string) ApiAuthControllerLoginRequest
Developer account email address.
func (ApiAuthControllerLoginRequest) Execute ¶
func (r ApiAuthControllerLoginRequest) Execute() (*http.Response, error)
func (ApiAuthControllerLoginRequest) Password ¶
func (r ApiAuthControllerLoginRequest) Password(password string) ApiAuthControllerLoginRequest
Account password.
type ApiAuthControllerLogoutRequest ¶
type ApiAuthControllerLogoutRequest struct {
ApiService *DeveloperAuthAPIService
// contains filtered or unexported fields
}
type ApiAuthControllerSignupRequest ¶
type ApiAuthControllerSignupRequest struct {
ApiService *DeveloperAuthAPIService
// contains filtered or unexported fields
}
func (ApiAuthControllerSignupRequest) Company ¶
func (r ApiAuthControllerSignupRequest) Company(company string) ApiAuthControllerSignupRequest
Company or team name.
func (ApiAuthControllerSignupRequest) ConfirmPassword ¶
func (r ApiAuthControllerSignupRequest) ConfirmPassword(confirmPassword string) ApiAuthControllerSignupRequest
Password confirmation.
func (ApiAuthControllerSignupRequest) Email ¶
func (r ApiAuthControllerSignupRequest) Email(email string) ApiAuthControllerSignupRequest
Work email used for dashboard access and API key delivery.
func (ApiAuthControllerSignupRequest) Execute ¶
func (r ApiAuthControllerSignupRequest) Execute() (*http.Response, error)
func (ApiAuthControllerSignupRequest) FullName ¶
func (r ApiAuthControllerSignupRequest) FullName(fullName string) ApiAuthControllerSignupRequest
Full name for the developer account.
func (ApiAuthControllerSignupRequest) Password ¶
func (r ApiAuthControllerSignupRequest) Password(password string) ApiAuthControllerSignupRequest
Account password.
type ApiSimSwapControllerCheckSimSwapRequest ¶
type ApiSimSwapControllerCheckSimSwapRequest struct {
ApiService *SIMSwapIntelligenceAPIService
// contains filtered or unexported fields
}
func (ApiSimSwapControllerCheckSimSwapRequest) CheckSimSwapDto ¶
func (r ApiSimSwapControllerCheckSimSwapRequest) CheckSimSwapDto(checkSimSwapDto CheckSimSwapDto) ApiSimSwapControllerCheckSimSwapRequest
func (ApiSimSwapControllerCheckSimSwapRequest) Execute ¶
func (r ApiSimSwapControllerCheckSimSwapRequest) Execute() (*SimSwapResponseDto, *http.Response, error)
func (ApiSimSwapControllerCheckSimSwapRequest) XAPIKey ¶
func (r ApiSimSwapControllerCheckSimSwapRequest) XAPIKey(xAPIKey string) ApiSimSwapControllerCheckSimSwapRequest
Developer API key. Alternative: Authorization: Bearer <KEY>.
type BasicAuth ¶
type BasicAuth struct {
UserName string `json:"userName,omitempty"`
Password string `json:"password,omitempty"`
}
BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth
type CheckSimSwapDto ¶
type CheckSimSwapDto struct {
// Subscriber phone number in strict E.164 format. Supports global numbering plans (e.g. +1 US, +49 DE, +234 NG Airtel/MTN).
PhoneNumber string `json:"phoneNumber" validate:"regexp=^\\\\+[1-9]\\\\d{1,14}$"`
// Maximum acceptable age, in hours, for SIM-swap intelligence.
MaxAgeHours *float32 `json:"maxAgeHours,omitempty"`
}
CheckSimSwapDto struct for CheckSimSwapDto
func NewCheckSimSwapDto ¶
func NewCheckSimSwapDto(phoneNumber string) *CheckSimSwapDto
NewCheckSimSwapDto instantiates a new CheckSimSwapDto object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed
func NewCheckSimSwapDtoWithDefaults ¶
func NewCheckSimSwapDtoWithDefaults() *CheckSimSwapDto
NewCheckSimSwapDtoWithDefaults instantiates a new CheckSimSwapDto object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set
func (*CheckSimSwapDto) GetMaxAgeHours ¶
func (o *CheckSimSwapDto) GetMaxAgeHours() float32
GetMaxAgeHours returns the MaxAgeHours field value if set, zero value otherwise.
func (*CheckSimSwapDto) GetMaxAgeHoursOk ¶
func (o *CheckSimSwapDto) GetMaxAgeHoursOk() (*float32, bool)
GetMaxAgeHoursOk returns a tuple with the MaxAgeHours field value if set, nil otherwise and a boolean to check if the value has been set.
func (*CheckSimSwapDto) GetPhoneNumber ¶
func (o *CheckSimSwapDto) GetPhoneNumber() string
GetPhoneNumber returns the PhoneNumber field value
func (*CheckSimSwapDto) GetPhoneNumberOk ¶
func (o *CheckSimSwapDto) GetPhoneNumberOk() (*string, bool)
GetPhoneNumberOk returns a tuple with the PhoneNumber field value and a boolean to check if the value has been set.
func (*CheckSimSwapDto) HasMaxAgeHours ¶
func (o *CheckSimSwapDto) HasMaxAgeHours() bool
HasMaxAgeHours returns a boolean if a field has been set.
func (CheckSimSwapDto) MarshalJSON ¶
func (o CheckSimSwapDto) MarshalJSON() ([]byte, error)
func (*CheckSimSwapDto) SetMaxAgeHours ¶
func (o *CheckSimSwapDto) SetMaxAgeHours(v float32)
SetMaxAgeHours gets a reference to the given float32 and assigns it to the MaxAgeHours field.
func (*CheckSimSwapDto) SetPhoneNumber ¶
func (o *CheckSimSwapDto) SetPhoneNumber(v string)
SetPhoneNumber sets field value
func (CheckSimSwapDto) ToMap ¶
func (o CheckSimSwapDto) ToMap() (map[string]interface{}, error)
func (*CheckSimSwapDto) UnmarshalJSON ¶
func (o *CheckSimSwapDto) UnmarshalJSON(data []byte) (err error)
type Configuration ¶
type Configuration struct {
Host string `json:"host,omitempty"`
Scheme string `json:"scheme,omitempty"`
DefaultHeader map[string]string `json:"defaultHeader,omitempty"`
UserAgent string `json:"userAgent,omitempty"`
Debug bool `json:"debug,omitempty"`
Servers ServerConfigurations
OperationServers map[string]ServerConfigurations
HTTPClient *http.Client
}
Configuration stores the configuration of the API client
func NewConfiguration ¶
func NewConfiguration() *Configuration
NewConfiguration returns a new Configuration object
func (*Configuration) AddDefaultHeader ¶
func (c *Configuration) AddDefaultHeader(key string, value string)
AddDefaultHeader adds a new HTTP header to the default header in the request
func (*Configuration) ServerURLWithContext ¶
ServerURLWithContext returns a new server URL given an endpoint
type DeveloperAuthAPIService ¶
type DeveloperAuthAPIService service
DeveloperAuthAPIService DeveloperAuthAPI service
func (*DeveloperAuthAPIService) AuthControllerLogin ¶
func (a *DeveloperAuthAPIService) AuthControllerLogin(ctx context.Context) ApiAuthControllerLoginRequest
AuthControllerLogin Authenticate a developer account
Accepts login credentials and redirects to the dashboard on success.
@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background(). @return ApiAuthControllerLoginRequest
func (*DeveloperAuthAPIService) AuthControllerLoginExecute ¶
func (a *DeveloperAuthAPIService) AuthControllerLoginExecute(r ApiAuthControllerLoginRequest) (*http.Response, error)
Execute executes the request
func (*DeveloperAuthAPIService) AuthControllerLogout ¶
func (a *DeveloperAuthAPIService) AuthControllerLogout(ctx context.Context) ApiAuthControllerLogoutRequest
AuthControllerLogout Sign out of the developer dashboard
@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background(). @return ApiAuthControllerLogoutRequest
func (*DeveloperAuthAPIService) AuthControllerLogoutExecute ¶
func (a *DeveloperAuthAPIService) AuthControllerLogoutExecute(r ApiAuthControllerLogoutRequest) (*http.Response, error)
Execute executes the request
func (*DeveloperAuthAPIService) AuthControllerSignup ¶
func (a *DeveloperAuthAPIService) AuthControllerSignup(ctx context.Context) ApiAuthControllerSignupRequest
AuthControllerSignup Create a developer account
Registers a developer account and redirects to the dashboard on success.
@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background(). @return ApiAuthControllerSignupRequest
func (*DeveloperAuthAPIService) AuthControllerSignupExecute ¶
func (a *DeveloperAuthAPIService) AuthControllerSignupExecute(r ApiAuthControllerSignupRequest) (*http.Response, error)
Execute executes the request
type GenericOpenAPIError ¶
type GenericOpenAPIError struct {
// contains filtered or unexported fields
}
GenericOpenAPIError Provides access to the body, error and model on returned errors.
func (GenericOpenAPIError) Body ¶
func (e GenericOpenAPIError) Body() []byte
Body returns the raw bytes of the response
func (GenericOpenAPIError) Error ¶
func (e GenericOpenAPIError) Error() string
Error returns non-empty string if there was an error.
func (GenericOpenAPIError) Model ¶
func (e GenericOpenAPIError) Model() interface{}
Model returns the unpacked model of the error
type LoginDto ¶
type LoginDto struct {
// Developer account email address.
Email string `json:"email"`
// Account password.
Password string `json:"password"`
}
LoginDto struct for LoginDto
func NewLoginDto ¶
NewLoginDto instantiates a new LoginDto object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed
func NewLoginDtoWithDefaults ¶
func NewLoginDtoWithDefaults() *LoginDto
NewLoginDtoWithDefaults instantiates a new LoginDto object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set
func (*LoginDto) GetEmailOk ¶
GetEmailOk returns a tuple with the Email field value and a boolean to check if the value has been set.
func (*LoginDto) GetPassword ¶
GetPassword returns the Password field value
func (*LoginDto) GetPasswordOk ¶
GetPasswordOk returns a tuple with the Password field value and a boolean to check if the value has been set.
func (LoginDto) MarshalJSON ¶
func (*LoginDto) SetPassword ¶
SetPassword sets field value
func (*LoginDto) UnmarshalJSON ¶
type MappedNullable ¶
type NullableBool ¶
type NullableBool struct {
// contains filtered or unexported fields
}
func NewNullableBool ¶
func NewNullableBool(val *bool) *NullableBool
func (NullableBool) Get ¶
func (v NullableBool) Get() *bool
func (NullableBool) IsSet ¶
func (v NullableBool) IsSet() bool
func (NullableBool) MarshalJSON ¶
func (v NullableBool) MarshalJSON() ([]byte, error)
func (*NullableBool) Set ¶
func (v *NullableBool) Set(val *bool)
func (*NullableBool) UnmarshalJSON ¶
func (v *NullableBool) UnmarshalJSON(src []byte) error
func (*NullableBool) Unset ¶
func (v *NullableBool) Unset()
type NullableCheckSimSwapDto ¶
type NullableCheckSimSwapDto struct {
// contains filtered or unexported fields
}
func NewNullableCheckSimSwapDto ¶
func NewNullableCheckSimSwapDto(val *CheckSimSwapDto) *NullableCheckSimSwapDto
func (NullableCheckSimSwapDto) Get ¶
func (v NullableCheckSimSwapDto) Get() *CheckSimSwapDto
func (NullableCheckSimSwapDto) IsSet ¶
func (v NullableCheckSimSwapDto) IsSet() bool
func (NullableCheckSimSwapDto) MarshalJSON ¶
func (v NullableCheckSimSwapDto) MarshalJSON() ([]byte, error)
func (*NullableCheckSimSwapDto) Set ¶
func (v *NullableCheckSimSwapDto) Set(val *CheckSimSwapDto)
func (*NullableCheckSimSwapDto) UnmarshalJSON ¶
func (v *NullableCheckSimSwapDto) UnmarshalJSON(src []byte) error
func (*NullableCheckSimSwapDto) Unset ¶
func (v *NullableCheckSimSwapDto) Unset()
type NullableFloat32 ¶
type NullableFloat32 struct {
// contains filtered or unexported fields
}
func NewNullableFloat32 ¶
func NewNullableFloat32(val *float32) *NullableFloat32
func (NullableFloat32) Get ¶
func (v NullableFloat32) Get() *float32
func (NullableFloat32) IsSet ¶
func (v NullableFloat32) IsSet() bool
func (NullableFloat32) MarshalJSON ¶
func (v NullableFloat32) MarshalJSON() ([]byte, error)
func (*NullableFloat32) Set ¶
func (v *NullableFloat32) Set(val *float32)
func (*NullableFloat32) UnmarshalJSON ¶
func (v *NullableFloat32) UnmarshalJSON(src []byte) error
func (*NullableFloat32) Unset ¶
func (v *NullableFloat32) Unset()
type NullableFloat64 ¶
type NullableFloat64 struct {
// contains filtered or unexported fields
}
func NewNullableFloat64 ¶
func NewNullableFloat64(val *float64) *NullableFloat64
func (NullableFloat64) Get ¶
func (v NullableFloat64) Get() *float64
func (NullableFloat64) IsSet ¶
func (v NullableFloat64) IsSet() bool
func (NullableFloat64) MarshalJSON ¶
func (v NullableFloat64) MarshalJSON() ([]byte, error)
func (*NullableFloat64) Set ¶
func (v *NullableFloat64) Set(val *float64)
func (*NullableFloat64) UnmarshalJSON ¶
func (v *NullableFloat64) UnmarshalJSON(src []byte) error
func (*NullableFloat64) Unset ¶
func (v *NullableFloat64) Unset()
type NullableInt ¶
type NullableInt struct {
// contains filtered or unexported fields
}
func NewNullableInt ¶
func NewNullableInt(val *int) *NullableInt
func (NullableInt) Get ¶
func (v NullableInt) Get() *int
func (NullableInt) IsSet ¶
func (v NullableInt) IsSet() bool
func (NullableInt) MarshalJSON ¶
func (v NullableInt) MarshalJSON() ([]byte, error)
func (*NullableInt) Set ¶
func (v *NullableInt) Set(val *int)
func (*NullableInt) UnmarshalJSON ¶
func (v *NullableInt) UnmarshalJSON(src []byte) error
func (*NullableInt) Unset ¶
func (v *NullableInt) Unset()
type NullableInt32 ¶
type NullableInt32 struct {
// contains filtered or unexported fields
}
func NewNullableInt32 ¶
func NewNullableInt32(val *int32) *NullableInt32
func (NullableInt32) Get ¶
func (v NullableInt32) Get() *int32
func (NullableInt32) IsSet ¶
func (v NullableInt32) IsSet() bool
func (NullableInt32) MarshalJSON ¶
func (v NullableInt32) MarshalJSON() ([]byte, error)
func (*NullableInt32) Set ¶
func (v *NullableInt32) Set(val *int32)
func (*NullableInt32) UnmarshalJSON ¶
func (v *NullableInt32) UnmarshalJSON(src []byte) error
func (*NullableInt32) Unset ¶
func (v *NullableInt32) Unset()
type NullableInt64 ¶
type NullableInt64 struct {
// contains filtered or unexported fields
}
func NewNullableInt64 ¶
func NewNullableInt64(val *int64) *NullableInt64
func (NullableInt64) Get ¶
func (v NullableInt64) Get() *int64
func (NullableInt64) IsSet ¶
func (v NullableInt64) IsSet() bool
func (NullableInt64) MarshalJSON ¶
func (v NullableInt64) MarshalJSON() ([]byte, error)
func (*NullableInt64) Set ¶
func (v *NullableInt64) Set(val *int64)
func (*NullableInt64) UnmarshalJSON ¶
func (v *NullableInt64) UnmarshalJSON(src []byte) error
func (*NullableInt64) Unset ¶
func (v *NullableInt64) Unset()
type NullableLoginDto ¶
type NullableLoginDto struct {
// contains filtered or unexported fields
}
func NewNullableLoginDto ¶
func NewNullableLoginDto(val *LoginDto) *NullableLoginDto
func (NullableLoginDto) Get ¶
func (v NullableLoginDto) Get() *LoginDto
func (NullableLoginDto) IsSet ¶
func (v NullableLoginDto) IsSet() bool
func (NullableLoginDto) MarshalJSON ¶
func (v NullableLoginDto) MarshalJSON() ([]byte, error)
func (*NullableLoginDto) Set ¶
func (v *NullableLoginDto) Set(val *LoginDto)
func (*NullableLoginDto) UnmarshalJSON ¶
func (v *NullableLoginDto) UnmarshalJSON(src []byte) error
func (*NullableLoginDto) Unset ¶
func (v *NullableLoginDto) Unset()
type NullableSignupDto ¶
type NullableSignupDto struct {
// contains filtered or unexported fields
}
func NewNullableSignupDto ¶
func NewNullableSignupDto(val *SignupDto) *NullableSignupDto
func (NullableSignupDto) Get ¶
func (v NullableSignupDto) Get() *SignupDto
func (NullableSignupDto) IsSet ¶
func (v NullableSignupDto) IsSet() bool
func (NullableSignupDto) MarshalJSON ¶
func (v NullableSignupDto) MarshalJSON() ([]byte, error)
func (*NullableSignupDto) Set ¶
func (v *NullableSignupDto) Set(val *SignupDto)
func (*NullableSignupDto) UnmarshalJSON ¶
func (v *NullableSignupDto) UnmarshalJSON(src []byte) error
func (*NullableSignupDto) Unset ¶
func (v *NullableSignupDto) Unset()
type NullableSimSwapResponseDto ¶
type NullableSimSwapResponseDto struct {
// contains filtered or unexported fields
}
func NewNullableSimSwapResponseDto ¶
func NewNullableSimSwapResponseDto(val *SimSwapResponseDto) *NullableSimSwapResponseDto
func (NullableSimSwapResponseDto) Get ¶
func (v NullableSimSwapResponseDto) Get() *SimSwapResponseDto
func (NullableSimSwapResponseDto) IsSet ¶
func (v NullableSimSwapResponseDto) IsSet() bool
func (NullableSimSwapResponseDto) MarshalJSON ¶
func (v NullableSimSwapResponseDto) MarshalJSON() ([]byte, error)
func (*NullableSimSwapResponseDto) Set ¶
func (v *NullableSimSwapResponseDto) Set(val *SimSwapResponseDto)
func (*NullableSimSwapResponseDto) UnmarshalJSON ¶
func (v *NullableSimSwapResponseDto) UnmarshalJSON(src []byte) error
func (*NullableSimSwapResponseDto) Unset ¶
func (v *NullableSimSwapResponseDto) Unset()
type NullableString ¶
type NullableString struct {
// contains filtered or unexported fields
}
func NewNullableString ¶
func NewNullableString(val *string) *NullableString
func (NullableString) Get ¶
func (v NullableString) Get() *string
func (NullableString) IsSet ¶
func (v NullableString) IsSet() bool
func (NullableString) MarshalJSON ¶
func (v NullableString) MarshalJSON() ([]byte, error)
func (*NullableString) Set ¶
func (v *NullableString) Set(val *string)
func (*NullableString) UnmarshalJSON ¶
func (v *NullableString) UnmarshalJSON(src []byte) error
func (*NullableString) Unset ¶
func (v *NullableString) Unset()
type NullableTime ¶
type NullableTime struct {
// contains filtered or unexported fields
}
func NewNullableTime ¶
func NewNullableTime(val *time.Time) *NullableTime
func (NullableTime) Get ¶
func (v NullableTime) Get() *time.Time
func (NullableTime) IsSet ¶
func (v NullableTime) IsSet() bool
func (NullableTime) MarshalJSON ¶
func (v NullableTime) MarshalJSON() ([]byte, error)
func (*NullableTime) Set ¶
func (v *NullableTime) Set(val *time.Time)
func (*NullableTime) UnmarshalJSON ¶
func (v *NullableTime) UnmarshalJSON(src []byte) error
func (*NullableTime) Unset ¶
func (v *NullableTime) Unset()
type SIMSwapIntelligenceAPIService ¶
type SIMSwapIntelligenceAPIService service
SIMSwapIntelligenceAPIService SIMSwapIntelligenceAPI service
func (*SIMSwapIntelligenceAPIService) SimSwapControllerCheckSimSwap ¶
func (a *SIMSwapIntelligenceAPIService) SimSwapControllerCheckSimSwap(ctx context.Context) ApiSimSwapControllerCheckSimSwapRequest
SimSwapControllerCheckSimSwap Run a real-time SIM-swap risk check
Checks a subscriber phone number against mocked global telecom registry intelligence and returns whether recent SIM-swap activity is present. Carrier resolution uses national mobile prefixes worldwide (Nigeria MTN/Airtel/Glo/9mobile, Germany Telekom/Vodafone/O2, US AT&T/T-Mobile/Verizon, UK, India, UAE, and more). Mock rule: numbers ending in 9 report a swap within the last 2 hours.
@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background(). @return ApiSimSwapControllerCheckSimSwapRequest
func (*SIMSwapIntelligenceAPIService) SimSwapControllerCheckSimSwapExecute ¶
func (a *SIMSwapIntelligenceAPIService) SimSwapControllerCheckSimSwapExecute(r ApiSimSwapControllerCheckSimSwapRequest) (*SimSwapResponseDto, *http.Response, error)
Execute executes the request
@return SimSwapResponseDto
type ServerConfiguration ¶
type ServerConfiguration struct {
URL string
Description string
Variables map[string]ServerVariable
}
ServerConfiguration stores the information about a server
type ServerConfigurations ¶
type ServerConfigurations []ServerConfiguration
ServerConfigurations stores multiple ServerConfiguration items
type ServerVariable ¶
ServerVariable stores the information about a server variable
type SignupDto ¶
type SignupDto struct {
// Full name for the developer account.
FullName string `json:"fullName"`
// Work email used for dashboard access and API key delivery.
Email string `json:"email"`
// Company or team name.
Company *string `json:"company,omitempty"`
// Account password.
Password string `json:"password"`
// Password confirmation.
ConfirmPassword string `json:"confirmPassword"`
}
SignupDto struct for SignupDto
func NewSignupDto ¶
func NewSignupDto(fullName string, email string, password string, confirmPassword string) *SignupDto
NewSignupDto instantiates a new SignupDto object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed
func NewSignupDtoWithDefaults ¶
func NewSignupDtoWithDefaults() *SignupDto
NewSignupDtoWithDefaults instantiates a new SignupDto object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set
func (*SignupDto) GetCompany ¶
GetCompany returns the Company field value if set, zero value otherwise.
func (*SignupDto) GetCompanyOk ¶
GetCompanyOk returns a tuple with the Company field value if set, nil otherwise and a boolean to check if the value has been set.
func (*SignupDto) GetConfirmPassword ¶
GetConfirmPassword returns the ConfirmPassword field value
func (*SignupDto) GetConfirmPasswordOk ¶
GetConfirmPasswordOk returns a tuple with the ConfirmPassword field value and a boolean to check if the value has been set.
func (*SignupDto) GetEmailOk ¶
GetEmailOk returns a tuple with the Email field value and a boolean to check if the value has been set.
func (*SignupDto) GetFullName ¶
GetFullName returns the FullName field value
func (*SignupDto) GetFullNameOk ¶
GetFullNameOk returns a tuple with the FullName field value and a boolean to check if the value has been set.
func (*SignupDto) GetPassword ¶
GetPassword returns the Password field value
func (*SignupDto) GetPasswordOk ¶
GetPasswordOk returns a tuple with the Password field value and a boolean to check if the value has been set.
func (*SignupDto) HasCompany ¶
HasCompany returns a boolean if a field has been set.
func (SignupDto) MarshalJSON ¶
func (*SignupDto) SetCompany ¶
SetCompany gets a reference to the given string and assigns it to the Company field.
func (*SignupDto) SetConfirmPassword ¶
SetConfirmPassword sets field value
func (*SignupDto) SetFullName ¶
SetFullName sets field value
func (*SignupDto) SetPassword ¶
SetPassword sets field value
func (*SignupDto) UnmarshalJSON ¶
type SimSwapResponseDto ¶
type SimSwapResponseDto struct {
// Subscriber phone number in E.164 format.
PhoneNumber string `json:"phoneNumber"`
// Whether the network registry indicates a recent SIM swap.
Swapped bool `json:"swapped"`
// ISO-8601 timestamp of the most recent SIM-swap signal.
LastSwappedAt *time.Time `json:"lastSwappedAt,omitempty"`
// Resolved mobile network operator or telecom provider (global prefix catalog).
Provider string `json:"provider"`
// Resolved mobile network operator. Alias retained for telco domain consumers.
Operator string `json:"operator"`
}
SimSwapResponseDto struct for SimSwapResponseDto
func NewSimSwapResponseDto ¶
func NewSimSwapResponseDto(phoneNumber string, swapped bool, provider string, operator string) *SimSwapResponseDto
NewSimSwapResponseDto instantiates a new SimSwapResponseDto object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed
func NewSimSwapResponseDtoWithDefaults ¶
func NewSimSwapResponseDtoWithDefaults() *SimSwapResponseDto
NewSimSwapResponseDtoWithDefaults instantiates a new SimSwapResponseDto object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set
func (*SimSwapResponseDto) GetLastSwappedAt ¶
func (o *SimSwapResponseDto) GetLastSwappedAt() time.Time
GetLastSwappedAt returns the LastSwappedAt field value if set, zero value otherwise.
func (*SimSwapResponseDto) GetLastSwappedAtOk ¶
func (o *SimSwapResponseDto) GetLastSwappedAtOk() (*time.Time, bool)
GetLastSwappedAtOk returns a tuple with the LastSwappedAt field value if set, nil otherwise and a boolean to check if the value has been set.
func (*SimSwapResponseDto) GetOperator ¶
func (o *SimSwapResponseDto) GetOperator() string
GetOperator returns the Operator field value
func (*SimSwapResponseDto) GetOperatorOk ¶
func (o *SimSwapResponseDto) GetOperatorOk() (*string, bool)
GetOperatorOk returns a tuple with the Operator field value and a boolean to check if the value has been set.
func (*SimSwapResponseDto) GetPhoneNumber ¶
func (o *SimSwapResponseDto) GetPhoneNumber() string
GetPhoneNumber returns the PhoneNumber field value
func (*SimSwapResponseDto) GetPhoneNumberOk ¶
func (o *SimSwapResponseDto) GetPhoneNumberOk() (*string, bool)
GetPhoneNumberOk returns a tuple with the PhoneNumber field value and a boolean to check if the value has been set.
func (*SimSwapResponseDto) GetProvider ¶
func (o *SimSwapResponseDto) GetProvider() string
GetProvider returns the Provider field value
func (*SimSwapResponseDto) GetProviderOk ¶
func (o *SimSwapResponseDto) GetProviderOk() (*string, bool)
GetProviderOk returns a tuple with the Provider field value and a boolean to check if the value has been set.
func (*SimSwapResponseDto) GetSwapped ¶
func (o *SimSwapResponseDto) GetSwapped() bool
GetSwapped returns the Swapped field value
func (*SimSwapResponseDto) GetSwappedOk ¶
func (o *SimSwapResponseDto) GetSwappedOk() (*bool, bool)
GetSwappedOk returns a tuple with the Swapped field value and a boolean to check if the value has been set.
func (*SimSwapResponseDto) HasLastSwappedAt ¶
func (o *SimSwapResponseDto) HasLastSwappedAt() bool
HasLastSwappedAt returns a boolean if a field has been set.
func (SimSwapResponseDto) MarshalJSON ¶
func (o SimSwapResponseDto) MarshalJSON() ([]byte, error)
func (*SimSwapResponseDto) SetLastSwappedAt ¶
func (o *SimSwapResponseDto) SetLastSwappedAt(v time.Time)
SetLastSwappedAt gets a reference to the given time.Time and assigns it to the LastSwappedAt field.
func (*SimSwapResponseDto) SetOperator ¶
func (o *SimSwapResponseDto) SetOperator(v string)
SetOperator sets field value
func (*SimSwapResponseDto) SetPhoneNumber ¶
func (o *SimSwapResponseDto) SetPhoneNumber(v string)
SetPhoneNumber sets field value
func (*SimSwapResponseDto) SetProvider ¶
func (o *SimSwapResponseDto) SetProvider(v string)
SetProvider sets field value
func (*SimSwapResponseDto) SetSwapped ¶
func (o *SimSwapResponseDto) SetSwapped(v bool)
SetSwapped sets field value
func (SimSwapResponseDto) ToMap ¶
func (o SimSwapResponseDto) ToMap() (map[string]interface{}, error)
func (*SimSwapResponseDto) UnmarshalJSON ¶
func (o *SimSwapResponseDto) UnmarshalJSON(data []byte) (err error)